@@ -37,6 +37,18 @@ def show_preservation(container_title: str, issn: str, volume: str,
     return preservations, doi
 
 
+def unpack_range(s):
+    """ Converts a range of numbers to a full set"""
+    r = []
+    for i in s.split(','):
+        if '-' not in i:
+            r.append(int(i))
+        else:
+            l, h = map(int, i.split('-'))
+            r += range(l, h + 1)
+    return r
+
+
 def show_preservation_for_doi(doi: str,
                               archive: str = None) -> (dict | None, str):
     """
